@@ -6,7 +6,6 @@
 
 #pragma once
 
-#include <QDBusContext>
 #include <QMap>
 #include <QObject>
 #include <QString>
@@ -20,7 +19,7 @@ class ConfigOperation;
 class Osd;
 class Output;
 
-class OsdManager : public QObject, public QDBusContext
+class OsdManager : public QObject
 {
     Q_OBJECT
 
@@ -30,7 +29,7 @@ public:
 
 public Q_SLOTS:
     void hideOsd();
-    OsdAction::Action showActionSelector();
+    void showActionSelector();
 
 private:
     void quit();
